All Classes and Interfaces
Class
Description
Annotation to be put on a test to cause a
InMemoryJobRepository to be cleared
after test execution.Time points when a
InMemoryJobStorage is cleared.Clears a
InMemoryJobStorage when so instructed by the presence of a ClearJobRepository
annotation.An alternative to
DefaultBatchConfiguration that sets up Spring Batch
with a in-memory JobRepository and JobExplorer and a default
JobLauncher and JobRegistry.In-memory implementation of
JobExplorer based on InMemoryJobStorage.Implementation of
JobRegistry that uses a HashMap
and ReadWriteLock instead of ConcurrentHashMap to
save memory.In-memory implementation of
JobExplorer based on JobRepository.Backing store for
InMemoryJobRepository and InMemoryJobExplorer.An alternative to
DefaultBatchConfiguration that sets up Spring Batch
with a null JobRepository and JobExplorer and a default
JobLauncher and JobRegistry.Deprecated.
Null implementation of
JobExplorerNull implementation of
JobExplorer
DataSource